@@ -66,3 +66,36 @@
 #	class(res) <- c("costatis", class(res))
 	return(res)
 }
+
+"costatis.randtest" <- function (KTX, KTY, nrepet = 999) {
+    if (!inherits(KTX, "ktab")) stop("The first argument must be a 'ktab'")
+    if (!inherits(KTY, "ktab")) stop("The second argument must be a 'ktab'")
+#### Parameters of first ktab
+    lwX <- KTX$lw
+    cwX <- KTX$cw
+    ncolX <- length(cwX)
+    bloX <- KTX$blo
+    ntabX <- length(KTX$blo)
+#### Parameters of second ktab
+    lwY <- KTY$lw
+    nligY <- length(lwY)
+    cwY <- KTY$cw
+    ncolY <- length(cwY)
+    bloY <- KTY$blo
+    ntabY <- length(KTY$blo)
+#### Tests of coherence of the two ktabs
+    if (ncolX != ncolY) stop("The two ktabs must have the same column numbers")
+    if (any(cwX != cwY)) stop("The two ktabs must have the same column weights")
+    if (ntabX != ntabY) stop("The two ktabs must have the same number of tables")
+    if (!all(bloX == bloY)) stop("The two tables of one pair must have the same number of columns")
+#### pta on KTX
+	ptaX <- pta(KTX, scannf = FALSE)
+#### pta on KTY
+	ptaY <- pta(KTY, scannf = FALSE)
+#### coinertia analysis of compromises
+	acpX=dudi.pca(t(ptaX$tab), center=FALSE, scannf=FALSE, nf=ptaX$nf)
+	acpY=dudi.pca(t(ptaY$tab), center=FALSE, scannf=FALSE, nf=ptaY$nf)
+	res <- coinertia(acpX, acpY, scannf = FALSE)
+	rtest1 <- randtest(res, nrepet = nrepet)
+	return(rtest1)
+}
